==> cxf-testutils-2.0.3.4-fuse-sources.jar: org/apache/type_test/xml/TestSequenceWithGroups.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types2.SequenceWithGroups;


/**
 * <p>Java class for testSequenceWithGroups element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testSequenceWithGroups">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types2}SequenceWithGroups"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types2}SequenceWithGroups"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testSequenceWithGroups")
public class TestSequenceWithGroups {

    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected SequenceWithGroups x;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected SequenceWithGroups y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link SequenceWithGroups }
     *     
     */
    public SequenceWithGroups getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link SequenceWithGroups }
     *     
     */
    public void setX(SequenceWithGroups value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link SequenceWithGroups }
     *     
     */
    public SequenceWithGroups getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link SequenceWithGroups }
     *     
     */
    public void setY(SequenceWithGroups value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.3-fuse-sources.jar: org/apache/type_test/xml/TestSequenceWithGroups.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types2.SequenceWithGroups;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types2}SequenceWithGroups"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types2}SequenceWithGroups"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testSequenceWithGroups")
public class TestSequenceWithGroups {

    @XmlElement(required = true)
    protected SequenceWithGroups x;
    @XmlElement(required = true)
    protected SequenceWithGroups y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link SequenceWithGroups }
     *     
     */
    public SequenceWithGroups getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link SequenceWithGroups }
     *     
     */
    public void setX(SequenceWithGroups value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link SequenceWithGroups }
     *     
     */
    public SequenceWithGroups getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link SequenceWithGroups }
     *     
     */
    public void setY(SequenceWithGroups value) {
        this.y = value;
    }

}
